package App::Nopaste::Service::Snitch;
use strict;
use warnings;
use base 'App::Nopaste::Service';

sub uri { "http://nopaste.snit.ch" }

=head1 NAME

App::Nopaste::Service::Snitch - http://nopaste.snit.ch/

=cut

1;

